@@ -1,3 +1,4 @@
+"All elements of freq_int are zero                                       ",&
 "Approximate Bayes cannot be run on a saturated model                    ",&
 "Approximate Bayes procedure aborted                                     ",&
 "Argument a or x is non-positive                                         ",&
@@ -10,6 +11,7 @@
 "Argument beta_series has incorrect size                                 ",&
 "Argument beta_vec has incorrect size                                    ",&
 "Argument criterion is not positive                                      ",&
+"Argument design_int has incorrect shape                                 ",&
 "Argument df is non-positive                                             ",&
 "Argument estimate_info has incorrect size                               ",&
 "Argument estimate_var_info has incorrect size                           ",&
@@ -30,6 +32,7 @@
 "Argument model_matrix has incorrect number of rows                      ",&
 "Argument mu has incorrect size                                          ",&
 "Argument n is non-positive                                              ",&
+"Argument n_clus has incorrect size                                      ",&
 "Argument offset has incorrect size                                      ",&
 "Argument omit has incorect length                                       ",&
 "Argument output_data has incorrect size                                 ",&
@@ -56,6 +59,7 @@
 "Argument vhat_beta has incorrect size                                   ",&
 "Argument vhat_beta_rwm has incorrect size                               ",&
 "Argument vhat_beta_vec has incorrect size                               ",&
+"Argument weight has incorrect size                                      ",&
 "Argument wkn has incorect length                                        ",&
 "Argument wkn1 or wkn2 has incorect length                               ",&
 "Argument wknp has incorect dimensions                                   ",&
@@ -67,10 +71,28 @@
 "Argument y has incorrect size                                           ",&
 "Arguments x and q have different dimensions                             ",&
 "Arguments x and y have incompatible dimensions                          ",&
+"Array baseline has incorrect size                                       ",&
+"Array beta has incorrect dimensions                                     ",&
 "Array bounds exceeded                                                   ",&
+"Array bounds exceeded for data_patt_st                                  ",&
+"Array cov_pattfor_data_patt has incorrect size                          ",&
+"Array freq_int_data_patt has incorrect size                             ",&
+"Array logP has insufficient size                                        ",&
+"Array logit_cov_patt has incorrect size                                 ",&
+"Array logit_data_patt has incorrect size                                ",&
+"Array loglik has insufficient size                                      ",&
+"Array n_cov_patt has incorrect size                                     ",&
+"Array n_data_patt has incorrect size                                    ",&
+"Array ncol_x has incorrect size                                         ",&
+"Array params has incorrect size                                         ",&
+"Array proportions_DAP has incorrect size                                ",&
+"Array row_posn_cov_patt has incorrect size                              ",&
+"Array row_posn_data_patt has incorrect size                             ",&
+"Array vhat_beta has incorrect size                                      ",&
 "Attempted division by zero                                              ",&
 "Attempted logarithm of non-positive number                              ",&
 "Attempted logarithn of non-positive number                              ",&
+"Bad data in cov_patt_for_data_patt                                      ",&
 "Bad row in data frame, positive freq for zero cells                     ",&
 "Bad row in input data                                                   ",&
 "Bad row in input data, positive freq for zero cells                     ",&
@@ -80,18 +102,39 @@
 "Bad row in pred_data                                                    ",&
 "Bad row in pred_data, with positive frequency                           ",&
 "Bad row in prior frame, positive freq for zero cells                    ",&
+"Bounds exceeded on array cov_patt_for_data_patt                         ",&
+"Bounds exceeded on array row_posn_cov_patt                              ",&
+"Bounds exceeded on array row_posn_data_patt                             ",&
+"Bounds exceeded on array xcol                                           ",&
+"Cluster indicator out of range                                          ",&
 "Cycle is already done                                                   ",&
 "Data inconsistent with structural zeros                                 ",&
 "Degrees of freedom are not positive                                     ",&
 "Dimensions of matrix arguments not conformable                          ",&
 "EM algorithm aborted                                                    ",&
+"EM algorithm for null model failed to converge by                       ",&
+"Element of baseline out of range                                        ",&
+"Element of cov_patt_for_data_patt out of range                          ",&
+"Element of freq_int is negative                                         ",&
+"Element of freq_int_data_patt is negative                               ",&
+"Element of n_clus is non-positive                                       ",&
+"Element of n_cov_patt not valid; must be at least 1                     ",&
+"Element of n_data_patt not valid; must be at least 1                    ",&
+"Element of ncol_x not valid; must be at least 1                         ",&
+"Element of row_posn_cov_patt out of range                               ",&
+"Element of row_posn_data_patt out of range                              ",&
 "Element of str_zero_int is not 0 or 1                                   ",&
+"Element of xcol out of range; exceeds bounds of pred                    ",&
+"Element of ystar out of range                                           ",&
+"Elements of freq_int_data_patt do not add up                            ",&
 "Error: stack size is too small                                          ",&
 "Estimate at or near boundary                                            ",&
 "Estimate has no variables                                               ",&
 "Estimated cov. matrix for beta not available                            ",&
 "Estimated variances may be unreliable                                   ",&
 "Failed to tabulate data                                                 ",&
+"Fewer than three measurement items                                      ",&
+"Fewer than two latent classes                                           ",&
 "First element of v is not 1.D0                                          ",&
 "Hessian apparently singular                                             ",&
 "Hessian matrix not neg-def                                              ",&
@@ -100,28 +143,42 @@
 "Incorrect model type                                                    ",&
 "Incorrect number of cells for estimate                                  ",&
 "Input argument vec has length zero                                      ",&
+"Insufficient data to define model                                       ",&
 "Invalid value in estimate_var_info, column 3                            ",&
 "Invalid value in lik_var_info, column 3                                 ",&
 "Length of vec(1) greater than max_string_length                         ",&
+"MCMC cannot be run with survey weights                                  ",&
 "MCMC procedure aborted                                                  ",&
+"Marginal proportions for DAP could not be computed                      ",&
 "Matrix apparently singular                                              ",&
 "Matrix not positive definite                                            ",&
 "Matrix vhat_beta not positive definite                                  ",&
 "Matrix vhat_beta_rm not positive definite                               ",&
 "Matrix vhat_beta_rwm not positive definite                              ",&
+"Method not recognized                                                   ",&
 "Metropolis-Hastings got stuck                                           ",&
 "Model matrix not full rank                                              ",&
+"NR algorithm aborted                                                    ",&
+"Negative cell mean encountered                                          ",&
 "Negative frequency for row of pred_data                                 ",&
 "Negative likelihood encountered                                         ",&
 "Negative probability encountered                                        ",&
+"Negative survey weight encountered                                      ",&
 "Negative value for burn_mcmc                                            ",&
 "Negative value for f_remaining                                          ",&
+"Negative value for flatten_em_null                                      ",&
 "Negative value for flattening constant                                  ",&
 "Negative value for impute_every                                         ",&
 "Negative value for iter_approx_bayes                                    ",&
 "Negative value for iter_max_EM                                          ",&
 "Negative value for iter_max_NR                                          ",&
+"Negative value for iter_max_em                                          ",&
+"Negative value for iter_max_em_item                                     ",&
+"Negative value for iter_max_em_null                                     ",&
+"Negative value for iter_max_nr                                          ",&
 "Negative value for iter_mcmc                                            ",&
+"Negative value for logit_prior_strength                                 ",&
+"Negative value for prior_freq_tot_DAP                                   ",&
 "Negative value for ridge factor                                         ",&
 "Negative value for start_val_jitter                                     ",&
 "Negative value for thin_mcmc                                            ",&
@@ -135,8 +192,13 @@
 "Non-positive value for crit_EM                                          ",&
 "Non-positive value for crit_NR                                          ",&
 "Non-positive value for crit_boundary                                    ",&
+"Non-positive value for crit_em                                          ",&
+"Non-positive value for crit_em_item                                     ",&
+"Non-positive value for crit_em_null                                     ",&
+"Non-positive value for crit_nr                                          ",&
 "Non-positive value for mcmc proposal df                                 ",&
 "Non-positive value for mcmc proposal scale_fac                          ",&
+"Non-positive value for n_strat                                          ",&
 "Non-square matrix encountered; square expected                          ",&
 "Non-zero prob provided for structural zero                              ",&
 "Non-zero starting value provided for structural zero                    ",&
@@ -146,30 +208,42 @@
 "Output argument does not match table type                               ",&
 "Overflow; cell mean became too large                                    ",&
 "Overflow; fitted value became too large                                 ",&
+"Overflow; jittered cell mean became too large                           ",&
 "Overflow; jittered cell prob became too large                           ",&
 "Overflow; offset too large                                              ",&
 "Pivot out of bounds                                                     ",&
+"Positive frequency seen for event of prob=0                             ",&
 "Posterior distribution is not proper;                                   ",&
 "Prior ridge factor ignored; model is saturated                          ",&
 "Random-walk Metropolis got stuck                                        ",&
+"Response has less than two levels                                       ",&
 "Size of n_levels_matrix not correct                                     ",&
 "Sizes of input_data and input_data_freq_int mismatched                  ",&
+"Sizes of pred and ystar mismatched                                      ",&
 "Sizes of prior_data and prior_data_freq_int mismatched                  ",&
 "Something bad happened                                                  ",&
 "Something really bad happened                                           ",&
 "Standard errors cannot be computed                                      ",&
 "Start, finish positions for estimate incorrect                          ",&
 "Starting value has non-positive probability                             ",&
+"Starting value in beta does not satisfy constraint                      ",&
 "Step size h is non-positive                                             ",&
 "Step size h is too large, exceeds a                                     ",&
+"Stratum indicator out of range                                          ",&
+"Stratum indicators not identical within clusters;                       ",&
+"Sub-population has no observations                                      ",&
 "Table object is null                                                    ",&
 "The model is not saturated                                              ",&
 "There is no log-linear model                                            ",&
+"This is not a logit model                                               ",&
+"This is not an lcmeas model                                             ",&
+"Total weight in sub-population is not positive                          ",&
 "Unable to allocate array                                                ",&
 "Unable to allocate memory for object                                    ",&
 "Unable to allocate workspace array component                            ",&
 "Unable to deallocate memory for object                                  ",&
 "Underflow; cell mean became zero                                        ",&
+"Underflow; jittered cell mean became zero                               ",&
 "Underflow; jittered cell prob became zero                               ",&
 "Underflow; offset too small                                             ",&
 "Upper limit b does not exceed lower limit a                             ",&
@@ -178,22 +252,28 @@
 "Value for stuck_limit not positive                                      ",&
 "Value for type_mcmc_int not recognized                                  ",&
 "Value in n_levels_matrix not correct                                    ",&
+"Value of baseline out of range                                          ",&
 "Value of exclude_all_na_int not recognized                              ",&
+"Value of logit_prior_int not recognized                                 ",&
 "Value of method not recognized                                          ",&
 "Value of model_type not recognized                                      ",&
+"Value of prior not recognized                                           ",&
 "Value of skip_SEs_int not recognized                                    ",&
 "Value of start_val_default not recognized                               ",&
 "Value of start_val_default_int not recognized                           ",&
 "Value of start_val_use_int not recognized                               ",&
 "Value of synthetic_int not recognized                                   ",&
 "Value of type_mcmc not recognized                                       ",&
+"Value supplied for class prevalence is not positive                     ",&
 "When creating mapping: allocation error                                 ",&
 "When creating mapping: array bounds exceeded                            ",&
 "Workspace wkn has incorrect length                                      ",&
 "Workspace wkp has incorrect length                                      ",&
 "Workspace wkp1 or wkp2 has incorrect length                             ",&
+"Zero probability assigned to non-empty levels                           ",&
 "assigned to structural zero cells                                       ",&
 "consider using a flattening prior                                       ",&
+"consider using nested=TRUE                                              ",&
 "estimate_type not recognized                                            ",&
 "iter_mcmc is not a multiple of thin_mcmc                                ",&
 "logP is not concave                                                     ",&
